# Contributing

> Alone we can do so little; together we can do so much. — Helen Keller

## Testing
TBD

## Code conventions
All code is formatted with the Black code formatter. This leaves little room for discussion on the code conventions and helps us focus on the actual quality of the code. More information on the Black formatter can be found here: [Python Black](https://github.com/ambv/black)

## Submitting changes
Any changes have to be commit to a feature branch and can only get into the master branch through an approved pull request. Please provide clear commit messages and pull requests so the reviewer knows what has changed and what the impact / effect is.
